@@ -27,55 +27,52 @@
 
 G_BEGIN_DECLS
 
+GType lsm_mathml_style_get_type (void);
+
+#define LSM_TYPE_MATHML_STYLE (lsm_mathml_style_get_type())
+
 struct _LsmMathmlStyle {
-	double math_size_value;
 	/* mstyle */
 	LsmMathmlDisplay display;
 
 	int script_level;
 	double script_size_multiplier;
-	LsmMathmlLength script_min_size;
+	double script_min_size;
 
-	LsmMathmlLength very_very_thin_math_space;
-	LsmMathmlLength very_thin_math_space;
-	LsmMathmlLength thin_math_space;
-	LsmMathmlLength medium_math_space;
-	LsmMathmlLength thick_math_space;
-	LsmMathmlLength very_thick_math_space;
-	LsmMathmlLength very_very_thick_math_space;
-
-	double very_very_thin_math_space_value;
-	double very_thin_math_space_value;
-	double thin_math_space_value;
-	double medium_math_space_value;
-	double thick_math_space_value;
-	double very_thick_math_space_value;
-	double very_very_thick_math_space_value;
+	double very_very_thin_math_space;
+	double very_thin_math_space;
+	double thin_math_space;
+	double medium_math_space;
+	double thick_math_space;
+	double very_thick_math_space;
+	double very_very_thick_math_space;
 	/* tokens */
 	char *math_family;
 	LsmMathmlVariant math_variant;
-	LsmMathmlLength math_size;
+	double math_size;
 	LsmMathmlColor math_color;
 	LsmMathmlColor math_background;
 	/* mfrac */
 	gboolean bevelled;
 	/* msubsup */
-	LsmMathmlLength subscript_shift;
-	LsmMathmlLength superscript_shift;
+	double subscript_shift;
+	double superscript_shift;
 	/* mfrac */
-	LsmMathmlLength line_thickness;
+	double line_thickness;
 };
 
 LsmMathmlStyle *	lsm_mathml_style_new 			(void);
-void		lsm_mathml_style_free 			(LsmMathmlStyle *style);
+void			lsm_mathml_style_free 			(LsmMathmlStyle *style);
 LsmMathmlStyle *	lsm_mathml_style_duplicate 		(const LsmMathmlStyle *from);
-void 		lsm_mathml_style_change_script_level 	(LsmMathmlStyle *style, int increment);
-void 		lsm_mathml_style_set_math_size_pt 		(LsmMathmlStyle *style, double math_size);
-void 		lsm_mathml_style_set_math_family 		(LsmMathmlStyle *style, const char *math_family);
-void 		lsm_mathml_style_set_math_variant		(LsmMathmlStyle *style, LsmMathmlVariant math_variant);
-void 		lsm_mathml_style_set_math_color 		(LsmMathmlStyle *style,
-							 double red, double green, double blue, double alpha);
-void 		lsm_mathml_style_dump 			(const LsmMathmlStyle *style);
+
+void 			lsm_mathml_style_change_script_level 	(LsmMathmlStyle *style, int increment);
+
+void 			lsm_mathml_style_set_math_size_pt 	(LsmMathmlStyle *style, double math_size);
+void 			lsm_mathml_style_set_script_min_size_pt	(LsmMathmlStyle *style, double script_min_size);
+void 			lsm_mathml_style_set_math_family 	(LsmMathmlStyle *style, const char *math_family);
+void 			lsm_mathml_style_set_math_variant	(LsmMathmlStyle *style, LsmMathmlVariant math_variant);
+void 			lsm_mathml_style_set_math_color 	(LsmMathmlStyle *style,
+								 double red, double green, double blue, double alpha);
 
 G_END_DECLS
 
